<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="31"/>
        <source>Scrobbler Plugin</source>
        <translation>Scrobbler-Modul</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>About Scrobbler Plugin</source>
        <translation>Über Scrobbler-Modul</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp AudioScrobbler-Modul</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Einstellungen Scrobbler-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Session:</source>
        <translation>Sitzung:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Check</source>
        <translation>Überprüfen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Register new session</source>
        <translation>Neue Sitzung registrieren</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="106"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <location filename="../settingsdialog.cpp" line="183"/>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>1. Wait for browser startup</source>
        <translation>1. Warten Sie auf den Start des Browsers</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="108"/>
        <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
        <translation>2. Erlauben Sie Qmmp das Scrobbeln von Titeln zu Ihrem %1-Konto</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>3. Press &quot;OK&quot;</source>
        <translation>3. Drücken Sie &quot;OK&quot;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <location filename="../settingsdialog.cpp" line="118"/>
        <location filename="../settingsdialog.cpp" line="147"/>
        <location filename="../settingsdialog.cpp" line="151"/>
        <location filename="../settingsdialog.cpp" line="191"/>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <location filename="../settingsdialog.cpp" line="147"/>
        <location filename="../settingsdialog.cpp" line="191"/>
        <source>Network error</source>
        <translation>Netzwerkfehler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <location filename="../settingsdialog.cpp" line="151"/>
        <source>Unable to register new session</source>
        <translation>Neue Sitzung ist nicht registrierfähig</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>New session has been received successfully</source>
        <translation>Neue Sitzung wurde erfolgreich empfangen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="183"/>
        <source>Permission granted</source>
        <translation>Berechtigung gewährt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Permission denied</source>
        <translation>Berechtigung gewährt</translation>
    </message>
</context>
</TS>
